Installation — Django AlphaFilter 0.6 documentation

Django AlphaFilter 0.6 documentation

# Installation

- Table of Contents
- index
  next
  previous

# Installation

1. The easiest method is to use `pip` or `easy_install`

       pip install django-alphafilter

   or

       easy_install django-alphafilter

2. If you download the source, you can install it by running the `setup.py` script:

       cd /path/to/django-alphafilter/
       python setup.py install

3. Add `'alphafilter'` to your project’s `settings.py` file, so Django will find the templates and template tag.

## Dependencies

None.